# Changelog

<!--next-version-placeholder-->

## v2.0.0 (2021-03-02)
### Feature
* easier manipulation of path and query ([`b520771`](https://github.com/MicaelJarniac/BuildURL/commit/b52077148eac94c668494ba08cfc41b8e2e91cfd))

### Breaking
* Renamed `_path_list` and `_query_dict`, and removed `params`.  ([`b520771`](https://github.com/MicaelJarniac/BuildURL/commit/b52077148eac94c668494ba08cfc41b8e2e91cfd))

### Documentation
* **contributing:** All Contributors info ([`5d2a84e`](https://github.com/MicaelJarniac/BuildURL/commit/5d2a84ebefb6324428a2df30200ef65aef0d7b9e))
* **readme:** better install & contrib. instruct. ([`05ca34b`](https://github.com/MicaelJarniac/BuildURL/commit/05ca34b0c6e8f395b41788c6ef270317aa80abf7))
* **readme:** basic installation and usage, badges ([`3718cbd`](https://github.com/MicaelJarniac/BuildURL/commit/3718cbdab9b414667a4252582086df4d6dace662))

## v1.1.4 (2021-02-26)


## v1.1.3 (2021-02-26)


## v1.1.2 (2021-02-26)


## v1.1.1 (2021-02-26)
### Fix
* query encoding ([`2b12860`](https://github.com/MicaelJarniac/BuildURL/commit/2b128607ed03e96238521d384fc86ba1f2a9e084))

### Documentation
* **readme:** coverage badge ([`aebb516`](https://github.com/MicaelJarniac/BuildURL/commit/aebb51623a1e276b3edc169b2f5d744d3ab0faed))

## v1.1.0 (2021-02-26)
### Feature
* initial commit ([`ff71a91`](https://github.com/MicaelJarniac/BuildURL/commit/ff71a9168cf932b602402b1ee764f27ea3a74517))

### Documentation
* **issue template:** initial commit ([`43e042a`](https://github.com/MicaelJarniac/BuildURL/commit/43e042af060181552e6923dcf86fef8a3e2e5997))
* **readme:** add badges ([`7d64626`](https://github.com/MicaelJarniac/BuildURL/commit/7d6462613b94f8f062bb0a5ab62bf01085af3a83))
* **contributing:** initial commit ([`da8c62b`](https://github.com/MicaelJarniac/BuildURL/commit/da8c62b087811b4fc20aa0a330271926140f9bfa))
